"""
__version__.py
~~~~~~~~~~~~~~

Information about the current version of the py-package-template package.
"""

__title__ = 'lambdasdk'
__description__ = 'for interacting with aws lambda'
__version__ = '0.0.11'
__author__ = 'Nic Wanavit'
__author_email__ = 'nwanavit@hatari.cc'
__license__ = 'Apache 2.0'
__url__ = 'https://github.com/thanakijwanavit/lambda-pip'



"""
py_pkg.entry_points.py
~~~~~~~~~~~~~~~~~~~~~~

This module contains the entry-point functions for the py_pkg module,
that are referenced in setup.py.
"""

from os import remove
from sys import argv
from zipfile import ZipFile

import requests


def main() -> None:
    """Main package entry point.

    Delegates to other functions based on user input.
    """

    try:
        user_cmd = argv[1]
        if user_cmd == 'install':
            install_template_from_github()
        else:
            RuntimeError('please supply a command for py_pkg - e.g. install.')
    except IndexError:
        RuntimeError('please supply a command for py_pkg - e.g. install.')
    return None


def install_template_from_github() -> None:
    """Installs the latest version of the template package project."""

    # check that the user really want to do this
    msg = 'Download Python package template project to this directory (y/n)? '
    user_response = input(msg)
    if user_response != 'y':
        return None

    # download ZIP archive of GitHub repository
    url = 'https://github.com/AlexIoannides/py-package-template/archive/master.zip'
    r = requests.get(url)
    with open('temp.zip', 'wb') as f:
        f.write(r.content)

    # extract ZIP file into calling directory
    with ZipFile('temp.zip', 'r') as repo_zip:
        repo_zip.extractall('.')

    # clean up
    remove('temp.zip')
    return None



from pprint import pprint
import boto3, base64, json

class Lambda:
    '''
      for invoking lambda functions
    '''
    def __init__(self, user=None, pw=None, region = 'ap-southeast-1'):
      self.lambdaClient = boto3.client(
          'lambda',
          aws_access_key_id=user,
          aws_secret_access_key=pw,
          region_name = region
        )
    def invoke(self, functionName, input):
      result = self.lambdaClient.invoke(
        FunctionName = functionName,
        InvocationType= 'RequestResponse',
        LogType='Tail',
        ClientContext= base64.b64encode(json.dumps({'caller': 'sdk'}).encode()).decode(),
        Payload= json.dumps(input)
      )
      if 'Payload' in result.keys():
          return json.loads(result['Payload'].read())
      else:
          return result
